;; Generated package description from consult-denote.el  -*- no-byte-compile: t -*-
(define-package "consult-denote" "0.2.1" "Use Consult in tandem with Denote" '((emacs "28.1") (denote "3.0.3") (consult "1.7")) :commit "eb46c0b19ea2c385d4e8f21c3e953fc621626cf2" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :url "https://github.com/protesilaos/consult-denote")
